Skip to contents

Takes the input list from def.para() or default_unit_list() and sets the corresponding columns in eddy.data.

Usage

assign_input_units(eddy.data, unitList, idepVar, speciesRatioName)

Arguments

eddy.data

input data

unitList

defaults to default_unit_list() plus species field based off of species argument speices is a list with names that match speciesRatioName describing the units per species. Defaults to mol mol-1Dry

idepVar

required if Algbase is trend or ord03. Name of column containing independant variable for determining the base function. Column gets duplicated to a column called "idep" use use in eddy4R.turb::def.stat.sta.diff. Default unixTime.

speciesRatioName

created automatically from species. name of gas species following the rtioMoleDry format