Skip to contents

Determine the files that correspond to the selected flux averaging period using a mask for the file name

Usage

def.avg(filePaths, fileNames, fileMask, fileDuration, aggregationDuration)

Arguments

filePaths

vector of file names

fileNames

vector of file paths

fileMask

string mask that can be passed to as.POSIXct(format = fileMask)

fileDuration

numeric length of files in seconds

aggregationDuration

numeric required flux duration

Author

W. S. Drysdale