Skip to contents

Apply a transformation to a wind vector based on particular codes:
e.g +veloXaxs will return the positive veloXaxs column, -veloXaxs will return veloXaxs*-1
Used in wrapper to apply user defined wind vector corrections
Function returns the column only so that the wrapper can handle reasssignment to data.frame
this is to avoid issues surrounding the order in which the function is applied

Usage

def.vect.orie(eddy.data, vec_id)

Arguments

eddy.data

eddy.data data.frame

vec_id

character string of format (+/-)(u/v/w)_met

Value

wind vector column with transformation applied

Author

W. S. Drysdale