Skip to contents

Returns a list containing the default units for temperature pressure and velocity. Useful as a base if the user needs to change the defaults in def.para()$unitList

Usage

default_unit_list()