Skip to contents

Apply transformations to wind vectors easily. Steps in order:
Use def.rot.mat to rotate around the uv plane - anemometerOffset
Apply W-boost correction to Gill Anemometers - wBoost

Usage

wrap.anem.cor(eddy.data, anemometerOffset, wBoost)

Arguments

eddy.data

eddy.data data.frame

anemometerOffset

rotation angle for uv plane of wind vectors (degrees)

wBoost

should w boost correction for certain Gill Anemometers be applied? Default false

Author

W. S. Drysdale