Skip to contents

Wrapper function to generate the statistical flags for sensors (PTR-Qi-TOF and CPEC200) which used in VOC comparison.

Usage

wrap.qf.voc(data, thshFile = NULL)

Arguments

data

Required input. A data frame containing the data to be evaluated.

thshFile

The file directory where the threshold table are being saved.

Value

qfPlau A list of data frame containing the calculated sensors quality flags and statistical flags

References

License: GNU AFFERO GENERAL PUBLIC LICENSE Version 3, 19 November 2007.

See also

Currently none

Author

Natchaya Pingintha-Durden ndurden@battelleecology.org