Skip to contents

Handles file reading, progress and error logging.

Usage

wrap.towr(paraMain, resume = NULL, thshFile = NULL, diagSens = FALSE)

Arguments

paraMain

parameters list made by def.para()

resume

loop iterator to restart at.

thshFile

The file directory where the threshold table are being saved. Default as NULL.

diagSens

Logical to state if the sensor diqgnostic flags are calculated. Default as FALSE.

Author

W. S. Drysdale