Skip to contents

Writes the data associated with the REYN (classical ec) processing.

Usage

write.REYN(REYN, lag_out, DirOut, analysis, tz, writeCompressedData, subDir)

Arguments

REYN

REYN List of objects at the end of calcualtions

lag_out

output list from wrap.lag()

DirOut

by default is created as file.path(DirWrk,"out",siteName, runID, analysis), can be overridden here.

analysis

Used in file nameing

tz

timezone, default "UTC".

writeCompressedData

TRUE/FALSE should the larger outputs that need compression ("ACF","foot", "spec", "base", "conv", "data","diff") outputs be written to disk. They will be compressed using gzip

subDir

one of c("none", "monthly", "daily") - default none. Should the outputs be split into monthly or daily subdirectories