Valid Input
def.valid.input.RdChecks input file for several key requirements
Number of rows !=0
Are required variables present? Skips the file if critcal vals are missing otherwise flags the optional variables that are missing
Are these columns the correct class
Are any of the stanard deviations of variables 0? Skip/flag as above
Check against the missing data threshold set in para
If there is no H20 data, set it to 1e-12.
Usage
def.valid.input(
eddy.data,
varsRequired,
varsCritical,
species,
speciesRatioName,
aggregationDuration,
periodStartDate,
periodEndDate,
missingThreshold,
freq,
logger
)Arguments
- eddy.data
input data
- varsRequired
character vector of columns that must be nominally present to pass def.valid.input()
- varsCritical
these must have greater than the missingThreshold to pass def.valid.input()
- species
vector of species names. Match with IntlNatu naming
- speciesRatioName
created automatically from species. name of gas species following the rtioMoleDry
format - aggregationDuration
flux aggregation period (s)
- periodStartDate
periodStartDate
- periodEndDate
periodEndDate
- missingThreshold
decimal percentage of missing data threshold per file
- freq
data aquisition frequency of input data
- logger
logger object