Define Vector Orientation
def.vect.orie.RdApply a transformation to a wind vector based on particular codes:
e.g +veloXaxs will return the positive veloXaxs column, -veloXaxs will return veloXaxs*-1
Used in wrapper to apply user defined wind vector corrections
Function returns the column only so that the wrapper can handle reasssignment to data.frame
this is to avoid issues surrounding the order in which the function is applied