Wrapper function: Determination of statistical flags for VOC flux comparison
wrap.qf.voc.RdWrapper function to generate the statistical flags for sensors (PTR-Qi-TOF and CPEC200) which used in VOC comparison.
Arguments
- data
Required input. A data frame containing the data to be evaluated.
- thshFile
The file directory where the threshold table are being saved.
Value
qfPlau A list of data frame containing the calculated sensors quality flags and statistical flags
Author
Natchaya Pingintha-Durden ndurden@battelleecology.org