Define Rotation of Wind Vectors
wrap.rot.RdPerform various types of wind vector rotations incl. single, double, planar fit.
Arguments
- data
data.frame containing veloXaxs, veloYaxs and veloZaxs
vectors should be defined correspondingly as u/v/w == E/N/U == x/y/z (data.frame)- MethRot
method of rotation to be used, one of:
"single" - rotate into the mean wind
"double" - apply single rotation and additionally rotate to align w and z (minimise w)
"planarFit" - apply the coefficeints for planat fit, supplied to plnrFitCoef.
Note that these coefficients should be determined in the coordinate system they are applied to."autoPlanrFit" - determine and apply the planar fit coefficeints from data.
"none" - perform no rotation
- plnrFitCoef
coefficients for planar fit. (numeric vector or data.frame)
Depending on plnrFitType, plnrFitCoef should be supplied as the following structure:simple - numeric vector constant of coefficeients, or coefficeients that are controlled from the workflow. c(al,be,b0)
time - data.frame with columns date, al, be, b0. values with date nearest to mean(data$date) will be used
wind - data.frame with columns PSI_uv, al, be, b0. values with PSI_uv nearest to average PSI_uv will be used
- plnrFitType
type of planar fit, "simple", "date" or "wind". (character vector)