Tower Wrapper
wrap.towr.RdHandles file reading, progress and error logging.
Arguments
- paraMain
parameters list made by
def.para()- resume
loop iterator to restart at.
- thshFile
The file directory where the threshold table are being saved. Default as NULL.
- diagSens
Logical to state if the sensor diqgnostic flags are calculated. Default as FALSE.